@@ -52,8 +52,14 @@ class ChattyAssetPreview(TimestampValidationMixin, BaseModel):
         return cls(**data)
 
     @classmethod
-    def from_asset(cls, asset: 'ChattyAssetModel') -> 'ChattyAssetPreview':
-        raise NotImplementedError(f"{cls.__name__} has no from_asset method")
+    def from_asset(cls, asset: 'CompanyAssetModel') -> 'ChattyAssetPreview':
+        return cls(
+            _id=asset.id,
+            name=getattr(asset, "name", "no name"),
+            company_id=asset.company_id,
+            created_at=asset.created_at,
+            updated_at=asset.updated_at
+        )
 
 class ChattyAssetModel(TimestampValidationMixin, UpdateableMixin, BaseModel):
     id: StrObjectId = Field(alias="_id", default_factory=lambda: str(ObjectId()), frozen=True)
