@@ -1,8 +1,6 @@
 from pydantic import BaseModel, Field
 from typing import List, Optional
 from enum import StrEnum
-from .related_asset import RelatedChattyAsset
-from letschatty.models.base_models.related_asset_mixin import RelatedAssetsMixin
 
 class ExampleElementType(StrEnum):
     """Type of an example element"""
@@ -15,7 +13,7 @@ class ExampleElement(BaseModel):
     type: ExampleElementType = Field(..., description="Type of the element")
     content: str = Field(..., description="Content of the element")
 
-class ChatExample(BaseModel, RelatedAssetsMixin):
+class ChatExample(BaseModel):
     """Example conversation for training the AI agent"""
     title: str = Field(..., description="Title/description of this example")
     content: List[ExampleElement] = Field(..., description="Sequence of elements in this example")
\ No newline at end of file
