@@ -1,10 +1,11 @@
-from pydantic import Field, ConfigDict, field_validator, SecretStr
+from pydantic import Field, ConfigDict, field_validator, SecretStr, model_validator
 from typing import Optional, List, Dict
 from ..base_models import ChattyAssetModel
 from letschatty.models.channels.channel import WhatsAppClientInfo
 
 class EmpresaModel(ChattyAssetModel):
     name: str = Field(description="The name of the company")
+    frozen_name: str = Field(description="The frozen name of the company", frozen=True)
     industry: Optional[str] = Field(default = "")
     url: Optional[str] = Field(default = "")
     allowed_origins: list[str] = Field(default_factory=lambda: [])
@@ -32,9 +33,16 @@ class EmpresaModel(ChattyAssetModel):
         populate_by_name=True
     )
 
+
+    @model_validator(mode="before")
+    def validate_frozen_name(cls, data: Dict) -> Dict:
+        if "frozen_name" not in data:
+            data["frozen_name"] = data["name"].replace(" ", "_")
+        return data
+
     @field_validator("name", mode="before")
     def validate_name(cls, v):
-        return v.replace(" ", "_")
+        return v
 
     @property
     def active_continuous_conversation_template_name(self) -> str:
