@@ -51,8 +51,10 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         document = asset.model_dump_json(serializer=SerializerType.DATABASE)
         document.pop('_id', None)  # Still needed
         result = self.collection.update_one({"_id": ObjectId(asset.id)}, {"$set": document})
-        if result.modified_count == 0:
+        if result.matched_count == 0:
             raise NotFoundError(f"No document found with id {asset.id}")
+        if result.modified_count == 0:
+            raise ValueError(f"No changes were made to the document with id {asset.id} probably because the values were the same")
         return asset.id
 
     def get_by_id(self, doc_id: str) -> T:
