@@ -2,6 +2,7 @@ from pydantic import BaseModel, Field
 from typing import Optional
 import logging
 import json
+from datetime import timedelta
 logger = logging.getLogger("logger")
 
 class Context(BaseModel):
@@ -166,9 +167,14 @@ class HumanInterventionRequired(CustomException):
         super().__init__(message, status_code=status_code, **context_data)
 
 class PostponeFollowUp(CustomException):
-    def __init__(self, message="Follow up postponed", status_code=400, **context_data):
+    def __init__(self, time_delta:timedelta,message="Follow up postponed", status_code=400, **context_data):
+        self.time_delta = time_delta
         super().__init__(message, status_code=status_code, **context_data)
 
 class SmartFollowUpStrategyNotSet(CustomException):
     def __init__(self, message="Smart follow up strategy not set", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class MissingAIAgentForSmartFollowUp(CustomException):
+    def __init__(self, message="Missing AI agent for smart follow up", status_code=400, **context_data):
         super().__init__(message, status_code=status_code, **context_data)
\ No newline at end of file
