@@ -4,7 +4,7 @@ from letschatty.models.company.empresa import EmpresaModel
 from letschatty.models.chat.flow_link_state import SmartFollowUpState
 from letschatty.models.company.assets.ai_agents.follow_up_strategy import FollowUpStrategy
 from letschatty.services.ai_agents import cot_follow_up_examples
-from letschatty.services.ai_agents.relevant_context_picker import RelevantContextPicker
+# from letschatty.services.ai_agents.relevant_context_picker import RelevantContextPicker
 from letschatty.services.ai_agents.context_builder import ContextBuilder
 from letschatty.models.utils.custom_exceptions.custom_exceptions import HumanInterventionRequired, PostponeFollowUp
 from letschatty.models.company.assets.ai_agents.chatty_ai_mode import ChattyAIMode
