@@ -271,6 +271,7 @@ class ChatService:
         )
         execution_context.set_event_time(assigned_asset.assigned_at)
         bisect.insort(chat.client.sales, assigned_asset)
+        ChatService.create_highlight(chat=chat, execution_context=execution_context, highlight_data=HighlightRequestData(title=f"🛍️ Venta de {product.name}", description=f"Venta de {product.name} creada por {execution_context.executor.name}", starred=False, subtype=MessageSubtype.SALE_ADDED))
         ChatService.add_central_notification_from_text(chat=chat, body=f"Venta de {product.name} agregada al chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.SALE_ADDED)
         return assigned_asset
 
@@ -279,6 +280,7 @@ class ChatService:
         """
         Update a sale for the chat.
         """
+        ChatService.create_highlight(chat=chat, execution_context=execution_context, highlight_data=HighlightRequestData(title=f"🛍️ Venta actualizada de {product.name}", description=f"Venta de {product.name} actualizada por {execution_context.executor.name}", starred=False, subtype=MessageSubtype.SALE_UPDATED))
         ChatService.add_central_notification_from_text(chat=chat, body=f"Venta de {product.name} actualizada en el chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.SALE_UPDATED)
         return sale
 
@@ -291,6 +293,7 @@ class ChatService:
             assigned_asset_to_remove = next(sale for sale in chat.client.sales if sale.asset_id == sale_id)
             chat.client.sales.remove(assigned_asset_to_remove)
             execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+            ChatService.create_highlight(chat=chat, execution_context=execution_context, highlight_data=HighlightRequestData(title=f"🛍️ Venta eliminada de {product.name}", description=f"Venta de {product.name} eliminada por {execution_context.executor.name}", starred=False, subtype=MessageSubtype.SALE_DELETED))
             ChatService.add_central_notification_from_text(chat=chat, body=f"Venta de {product.name} eliminada del chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.SALE_DELETED)
             return assigned_asset_to_remove
         except StopIteration:
@@ -310,6 +313,8 @@ class ChatService:
         ) #type: ignore
         execution_context.set_event_time(highlight.created_at)
         bisect.insort(chat.client.highlights, highlight)
+        # Sort highlights in descending order by created_at timestamp
+        chat.client.highlights.sort(reverse=True)
         ChatService.add_central_notification_from_text(chat=chat, body=f"Highlight {highlight.title} agregado al chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.HIGHLIGHT_ADDED)
         return highlight
 
@@ -330,6 +335,8 @@ class ChatService:
             updated_highlight = highlight_to_update.update(highlight)
             chat.client.highlights.remove(highlight_to_update)
             bisect.insort(chat.client.highlights, updated_highlight)
+            # Sort highlights in descending order by created_at timestamp
+            chat.client.highlights.sort(reverse=True)
             execution_context.set_event_time(updated_highlight.updated_at)
             CentralNotificationFactory.from_notification_body(f"Highlight {highlight_to_update.title} actualizado en el chat {chat.id} por {execution_context.executor.name}", MessageSubtype.HIGHLIGHT_UPDATED)
             return updated_highlight
@@ -344,6 +351,8 @@ class ChatService:
         try:
             highlight = next(highlight for highlight in chat.client.highlights if highlight.id == highlight_id)
             chat.client.highlights.remove(highlight)
+            # Sort highlights in descending order by created_at timestamp
+            chat.client.highlights.sort(reverse=True)
             execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
             ChatService.add_central_notification_from_text(chat=chat, body=f"Highlight #{highlight.title} eliminado del chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.HIGHLIGHT_DELETED)
             return highlight
