@@ -77,26 +77,34 @@ class ContinuousConversationHelper:
             return preview
 
     @staticmethod
-    def create_continuous_conversation(chat: Chat, messages:SendMessagesFromAgentToChat, execution_context: ExecutionContext) -> ContinuousConversation:
+    def create_continuous_conversation(chat: Chat, messages:List[MessageDraft], execution_context: ExecutionContext) -> ContinuousConversation:
         """
         Create a new continuous conversation from a list of messages.
         """
         active_cc = ContinuousConversationHelper.get_active_cc(chat)
         if active_cc:
             raise ValueError("There is already an active continuous conversation")
-        cc = ContinuousConversation(messages=messages.messages, creator_id=execution_context.executor.id, forced_send=messages.forced_send, created_at=datetime.now(ZoneInfo("UTC")), updated_at=datetime.now(ZoneInfo("UTC")))
+        cc = ContinuousConversation(messages=messages, creator_id=execution_context.executor.id, forced_send=False, created_at=datetime.now(ZoneInfo("UTC")), updated_at=datetime.now(ZoneInfo("UTC")))
         chat.continuous_conversations.append(cc)
         return cc
 
     @staticmethod
-    def update_continuous_conversation(chat: Chat, cc_id: str, messages: SendMessagesFromAgentToChat, execution_context: ExecutionContext) -> ContinuousConversation:
+    def create_continuous_conversation_for_phone_number_without_chat(phone_number:str, messages:List[MessageDraft], execution_context: ExecutionContext) -> ContinuousConversation:
+        """
+        Create a new continuous conversation from a list of messages.
+        """
+        cc = ContinuousConversation(messages=messages, creator_id=execution_context.executor.id, forced_send=False, created_at=datetime.now(ZoneInfo("UTC")), updated_at=datetime.now(ZoneInfo("UTC")))
+        return cc
+
+    @staticmethod
+    def update_continuous_conversation(chat: Chat, cc_id: str, messages: List[MessageDraft], execution_context: ExecutionContext) -> ContinuousConversation:
         """
         Update a continuous conversation from a list of messages.
         """
         cc = ContinuousConversationHelper.get_cc_by_id(chat=chat, cc_id=cc_id)
         if not cc.active:
             raise ValueError("Cannot update a non-active continuous conversation")
-        new_cc = ContinuousConversation(messages=messages.messages, creator_id=execution_context.executor.id, forced_send=messages.forced_send)  #type: ignore
+        new_cc = ContinuousConversation(_id=cc.id, messages=messages, creator_id=execution_context.executor.id, forced_send=False, created_at=datetime.now(ZoneInfo("UTC")), updated_at=datetime.now(ZoneInfo("UTC")))
         cc.messages = new_cc.messages
         cc.forced_send = new_cc.forced_send
         cc.expires_at = new_cc.expires_at
